#
# spec file for package xf86-video-nv
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-nv
Version:        2.1.22
Release:        1.5
Summary:        NVIDIA video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
Patch0:         xf86-video-nv-bug519261-increase-virtual.diff
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(pciaccess) >= 0.10.7
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.3
BuildRequires:  pkgconfig(xproto)
# better not install it by default (bnc#868732)
#Supplements:    modalias(xorg-x11-server:pci:v000010DEd*sv*sd*bc03sc*i*)
#Supplements:    modalias(xorg-x11-server:pci:v000012D2d*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
Provides:       xorg-x11-driver-video-nvidia = %{version}
Obsoletes:      xorg-x11-driver-video-nvidia < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x
%x11_abi_videodrv_req

%description
nv is an Xorg driver for NVIDIA video cards.

The driver supports 2D acceleration and provides support for the
following framebuffer depths: 8, 15, 16 (except Riva128) and 24. All
visual types are supported for depth 8, TrueColor and DirectColor
visuals are supported for the other depths with the exception of the
Riva128 which only supports TrueColor in the higher depths.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%license COPYING
%doc README.md
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/nv_drv.so
%{_datadir}/man/man4/nv.4%{?ext_man}

%changelog
* Thu Jul 28 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.1.22
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Update README.G80 for gitlab migration
  * riva_xaa: don't build RivaSetRopPattern when XAA is not supported
  * autogen.sh: Implement GNOME Build API
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: use exec instead of waiting for configure to finish
  * Replace xf86PciInfo.h with our own pci ids
* Mon May 29 2017 sndirsch@suse.com
- commented out modalias lines in specfile in order to no longer
  install xf86-video-nv driver by default (bnc#868732, bsc#1041416)
- covers missing SLE entry fate#320388 (bsc#1041416)
* Thu Jan 19 2017 sndirsch@suse.com
- Update to version 2.1.21:
  * Remove mibstore.h
  * Adapt Block/WakeupHandler signature for ABI 23
  * init: Initialize VGA IOBase before using it
  * Include xf86Modes.h to use functions from hw/xfree86/modes/xf86Modes.c.
  * Fix shadow framebuffer implementation.
- supersedes U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch,
  U_Include-xf86Modes.h-to-use-functions-from-hw-xfree86.patch,
  U_Remove-mibstore.h.patch,
  U_init-Initialize-VGA-IOBase-before-using-it.patch
* Wed Nov 30 2016 sndirsch@suse.com
- U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
  * Adapt Block/WakeupHandler signature for ABI 23
* Mon Dec  2 2013 sndirsch@suse.com
- U_Include-xf86Modes.h-to-use-functions-from-hw-xfree86.patch
  * Include xf86Modes.h to use functions from
    hw/xfree86/modes/xf86Modes.c.
- U_init-Initialize-VGA-IOBase-before-using-it.patch
  * init: Initialize VGA IOBase before using it; The NV driver did
    never set the VGA IOBase for those registers which have
    different addresses dependent whether the VGA engine is running
    in mono or color mode. This has not been detected as the VGA
    mode and font save/restore functions initialize this value
    themselves.
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Thu Mar 21 2013 sndirsch@suse.de
- Add mibstore.patch, fixes build with xorg-server 1.14
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Wed Jul 25 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.1.20:
  + Make failure to XAA non-fatal
  + Fix for new vgahw ABI (bnc#770560)
  + Sun's copyrights now belong to Oracle
  + nv: port to new compat API.
  + nv: make XAA optional.
  + nv: add missing fbman includes.
  + remove duplicated includes
* Fri Apr 20 2012 vuntz@opensuse.org
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-nv from xorg-x11-driver-video.
  Initial version: 2.1.18.
